In particular, the *Trip on a lift* notebook allows learning step-by-step how to evaluate velocity and acceleration, and highlights also the concept of negative velocity. The experimental investigation of *Projectile motion* allows to detect and compare directly a case of constant velocity with a case of constant (negative) acceleration, while looking specifically at the motion along the two axes.

### The power of images
Images and videos can be used to better describe a problem or for gaining the attention of the readers (*Earh to Moon distance*, *Long distance communications*), but they also become tools for running experiments, for instance by means of video capturing.

### Python **AND** open-source software
The notebooks refer not only to Python cod but also to free and open-source applications such as for instance [Phyphox](https://phyphox.org), an App turning the smartphone into a mobile lab. We use the [Tracker](https://physlets.org/tracker/) package for recording videos of the experiments and for extracting the coordinates of the object as a function of time. Finally, we use the [Audacity](https://audacityteam.org) software for recording sounds, for Fourier analysis of audio traces, and for generating tones at a desired frequency. 
Along with simple and inexpensive experiments, suitable to be performed also in distance-learning settings, and open-source Apps, the Jupyter Notebook can be used to wrap up the information in an optimized way.
    

### The importance of definitions 
Angles, trigonometric functions, and vectors remain topics not well understood by many freshmen. A thorough understanding of these, however, is fundamental for taking full advantage of physics courses. For this reason, the workbooks contain a section with supplementary materials in which readers can play with the measurements of angles, or with the values of trigonometric functions, and can visualize vectors as well as the results of operations on them.

### Mark the route
"How did we do this?" Several times you need to do something similar to a project that you developed previously, but you do not remember the details of how you arrived to that beautiful result. Taking notes that are going to be helpful for future work should become a habit. For this reason, every notebook of our collection also contains references, notes, and URLs.  


### Use reliable sources
 Nowadays we often find many suggestions by searching the Internet, blogs, discussion groups, etc.; it is very useful to have good references to start with: books, online courses, original documentation of software packages. Using verified sources should be recommended.


## How to better exploit this material
The collection Simple Physics with Python can be viewed via a web browser, in its public [GitHub](https://github.com/POSS-UniMe/simple-physics-with-Python) repository. The Jupyter notebooks can also be rendered under the [**nbviewer**](https://nbviewer.org/) application. Each notebook also has a button to launch the [**binder**](https://mybinder.org/) environment, which allows to use the notebook in an interactive mode even if Python is not installed on the user's computer. Some tens of seconds will be needed to load the environment. The notebooks can be read also on smartphones, but some of the interactive objects, like the slider widgets, become then more difficult to use.
A suggested way to exploit this GitHub resource is for the user to install the [Anaconda](https://www.anaconda.com/products/individual) package, dowload a clone of the repository, and run the notebooks on their local machine. Other services like [Google Colab](https://colab.research.google.com/) could be used to develop and run the notebooks on a cloud platform, with no need to install applications on the local machine. On the other hand, Jupyter allows preparing the notebooks while working offline.

## This work was inspired by
* Lorena Barba, [Engineering Computations](https://github.com/engineersCode/EngComp)[5].
* David J. Pine, [Introduction to Python for Science](https://physics.nyu.edu/pine/pymanual/html/pymanMaster.html)[6].
* Lorena Barba and Olivier Mesnard Olivier, [Aero Python: classical aerodynamics of potential flow using Python](https://github.com/barbagroup/AeroPython)[7].

## Outcomes and further work
The work for developing these thematic notebooks on Simple Physics with Python has led us to experience a different way of teaching, and to provide students with new tools towards quality education. We have used the notebooks in several contexts. Other than in lectures, we exploited them for laboratory activities and meetings or events for young students. We would like to improve and extend the materials to cover other topics on general physics.

## Concluding remarks
The collection Simple Physics with Python can be used for remote learning projects, courses and presentations for prospective students. We hope this helps students to approach physics but also interest readers to glimpse the advantages of Python and of the Jupyter environment for scientific purposes.
Specifically, in the notebooks we like to propose *a* method to solve a problem, which is not *the* only one, neither *the best* one necessarily. This concerns both physics and coding in Python. 
We hope to raise in users their curiosity for physics with open-source software and inexpensive hardware, stimulating at the same time a hands-on approach in learning.

# Acknowledgements
We thank the Editor-in-Chief Lorena Barba and the Department Editors Dirk Colbry and Sharon Broude Geva for insightful comments and suggestions.

## References
1. Lorena A. Barba, Lecia J. Barker, Douglas S. Blank, Jed Brown, Allen B. Downey, Timothy George, Lindsey J. Heagy, Kyle T. Mandli, Jason K. Moore, David Lippert, Kyle E. Niemeyer, Ryan R. Watkins, Richard H. West, Elizabeth Wickes, Carol Willing, and Michael Zingale, [Teaching and learning with Jupyter](https://jupyter4edu.github.io/jupyter-edu-book/index.html),  Open book (2019)
2. Achinthya Rao, [Standing on the shoulders of programmers: the power of free and open-source software](https://physicsworld.com/a/standing-on-the-shoulders-of-programmers/), Physics World, September 2021
3. Jana Lasser, [Creating an executable paper is a journey through Open Science](https://www.nature.com/articles/s42005-020-00403-4), Communication Physics, 3 (2020), 143.
4. Andrea Mandanici,  Giuseppe Mandaglio, Giovanni Pirrotta, Valeria Conti Nibali, Giacomo Fiumara, [Simple Physics with Python](https://github.com/POSS-UniMe/simple-physics-with-Python), GitHub.
5. Lorena Barba, [Engineering Computations](https://github.com/engineersCode/EngComp), Computing in Science & Engineering, 22(4), pp.26-35,"Engineers Code: reusable open learning modules for engineering computations" 2020, doi:10.1109/MCSE.2020.2976002, preprint on arXiv::2001.00228.
6. David J. Pine, [Introduction to Python for Science](https://physics.nyu.edu/pine/pymanual/html/pymanMaster.html) and [Introduction to Python for Science and Engineering (1st ed.)](https://www.routledge.com/Introduction-to-Python-for-Science-and-Engineering/Pine/p/book/9781138583894) CRC press (2019). https://doi.org/10.1201/9780429506413
7. Barba, Lorena A., and Mesnard, Olivier (2019). [Aero Python: classical aerodynamics of potential flow using Python](https://github.com/barbagroup/AeroPython). Journal of Open Source Education, 2(15), 45, (https://doi.org/10.21105/jose.00045)


## The authors
* **Andrea Mandanici** is associate professor of experimental physics at the University of Messina. He teaches physics courses for the Degree in Computer Science and for the Degree in Mathematics. He's coworking on activities concerning Physics with Open Source Software. He is corresponding author of this article.
* **Giuseppe Mandaglio** is associate professor of particle physics at the University of Messina. He teaches courses on Data Analysis and Particle Physics Laboratory for the Degree in Physics and for the Master in Physics. He's Coordinator of the Degree Course in Physics, Coordinator of the master's degree course in Physics, and member of the doctoral school of Physics of the University of Messina. He's author of course materials on C++ and on data analysis with the use of the ROOT framework developed by CERN. He is corresponding author of this article.
* **Giovanni Pirrotta**, Master in Computer Science and PhD in Mathematics, is IT expert staff member of the University of Messina. He's author of projects and publications on Open Data.
* **Valeria Conti Nibali**, is tenure-track professor at the University of Messina and teaches Physics for the Bachelor's Degree in Computer Science - Data Analysis. Her research interests are in Computational and Experimental  Condensed Matter Physics and Biophysics.
* **Giacomo Fiumara** is associate professor at the University of Messina, senior member of the board of professors of the bachelor's degree in computer science, and of the master's degree in engineering and computer science with the University of Messina. He is a member of the doctoral board of the School of Mathematics and Computational Sciences, University of Palermo. He also teaches bioinformatics for the international degree course in medicine and surgery. His research interests include social network analysis, data analysis, information system analysis, parallel computing, parallel and distributed algorithms for the analysis of large-scale networks, statistical physics, and condensed-matter physics. 